/* $Id: dialog.h,v 1.6 2007/07/15 22:05:22 mgdepalma Exp $
 *
 * Copyright (C) 2007 Softcraft Impresa, LLC <info@softcraft.org>
 *
 * This program is free software; you can redistribute it and/or modify
 * it under the terms of the GNU General Public License as published by
 * the Free Software Foundation; You may only use version 2 of the License,
 * you have no option to use any other version.
 *
 * This program is distributed in the hope that it will be useful,
 * but WITHOUT ANY WARRANTY; without even the implied warranty of
 * MERCHANTABILITY or FITNESS FOR A PARTICULAR PURPOSE.  See the
 * GNU General Public License for more details.
 *
 * You should have received a copy of the GNU General Public License
 * along with this program; if not, write to the Free Software
 * Foundation, Inc., 675 Mass Ave, Cambridge, MA 02139, USA.
 */

#ifndef DIALOG_H
#define DIALOG_H

#include <errno.h>
#include <string.h>
#include <sys/stat.h>
#include <unistd.h>

#include <gtk/gtk.h>
#include <gdk/gdkx.h>

#include "filechooser.h"
#include "xpmglyphs.h"
#include "print.h"

/* Definitions for image file type */
typedef enum {
  PNG,
  JPEG,
  BMP,
  PostScript
} FileType;

typedef struct {
  FileType type;
  gchar    *extension;
} FileBinding;

/* Data structure definition for generic gtk_dialog */
typedef struct _dialogue Dialogue;

struct _dialogue {
  GtkWidget *window;
  GtkWidget *layout;
  GtkWidget *cancel;
  GtkWidget *apply;
};

/* Data structure definition for print image dialog */
typedef struct _print_dialog PrintDialog;

struct _print_dialog {
  FileChooser *chooser;		/* file chooser instance */
  GtkFunction callback;		/* callback on save      */

  GtkWidget *parent;		/* parent window         */
  GtkWidget *dialog;		/* main dialog window    */
  GtkWidget *filer;		/* file chooser area     */

  gint width, height;		/* dialog minimal size   */

  GtkWidget *command;		/* print command entry   */
  GtkWidget *outfile;		/* print to file switch  */

  FileType imagetype;		/* image file type       */
  gboolean landscape;		/* landscape orientation */
  int device;			/* print device          */
  int paper;			/* PaperSize index       */
};

/* Data structure definition for save file dialog */
typedef struct _save_dialog SaveDialog;

struct _save_dialog {
  GtkWidget *parent;		/* parent window         */
  GtkWidget *dialog;		/* main dialog window    */
  GtkWidget *filer;		/* file chooser area     */

  GtkFunction callback;		/* callback on save      */
  GtkWidget   *options;		/* image type menu       */
  FileChooser *chooser;		/* file chooser instance */
  FileType    imgtype;		/* image file type       */

  GtkWidget *cancel;		/* cancel button         */
  GtkWidget *apply;		/* confirm button        */
};


/* Method exported by chooser implementation */
extern const gchar *get_file_extension(FileType index);

extern GtkWidget *add_button(GtkWidget *dialog, IconIndex index,
                             gchar *label, GtkResponseType handle);
extern void remove_button(GtkWidget *dialog, GtkWidget* button);

extern GtkWidget *add_filetypes(GtkWidget **list);
extern void set_file_type(GtkWidget *dialog, gpointer value);

extern GtkWidget *add_papersize(PaperSize *list);
extern void set_papersize(GtkWidget *widget, gpointer value);

extern GtkWidget *add_printers(GList *list);
extern void set_printer(GtkWidget *widget, gpointer value);

extern void add_horizontal_separator(GtkWidget* layout);
extern void add_horizontal_space(GtkWidget* layout, gint space);
extern void add_vertical_space(GtkWidget* layout, gint space);

extern GtkWidget *make_menu_item(gchar *name,GCallback callback,gpointer data);

extern PrintDialog *printdialog_new (GtkWidget *parent, GtkFunction callback);
extern SaveDialog  *savedialog_new  (GtkWidget *parent, GtkFunction callback);

extern gint notice(GtkWidget *parent, IconIndex icon, const gchar* text);
extern gint overwrite(GtkWidget *parent, const gchar* filename);
extern void unimplemented(GtkWidget *parent, const gchar* feature);

#endif /* </DIALOG_H> */
